Module unstable

Module unstable 

Unstable traits and types.

All traits and types in this module are unstable. They could change in the future.

Traits

VariantCore
Mark a type as a newtype variant of an Enum E.